==> haskell-hslua-module-text-0.1.2.1-35-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-text
version: 0.1.2.1
id: hslua-module-text-0.1.2.1-II5xZ2o1khDEMUduksFfcw
key: hslua-module-text-0.1.2.1-II5xZ2o1khDEMUduksFfcw
license: MIT
copyright: © 2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-test
synopsis: Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.
category: Foreign
abi: 5f15083698048d223bff61f1685a23e8
exposed: True
exposed-modules:
    Foreign.Lua.Module.Text
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hslua-module-text-0.1.2.1
hs-libraries: HShslua-module-text-0.1.2.1-II5xZ2o1khDEMUduksFfcw
depends:
    base-4.11.1.0 hslua-0.9.5.2-Ev2R9AZ6IUJBYbwxnWTv9u text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hslua-0.9.5.2-Ev2R9AZ6IUJBYbwxnWTv9u=3021272dbab559de833e60d25f0a5b5d
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-0.1.2.1-36-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-text
version: 0.1.2.1
id: hslua-module-text-0.1.2.1-K4GfIrO5QnpLtE7MQ9tZwg
key: hslua-module-text-0.1.2.1-K4GfIrO5QnpLtE7MQ9tZwg
license: MIT
copyright: © 2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/hslua-module-test
synopsis: Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.
category: Foreign
abi: e1437e2c932edf301b1926d94e684f15
exposed: True
exposed-modules:
    Foreign.Lua.Module.Text
import-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hslua-module-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hslua-module-text-0.1.2.1
hs-libraries: HShslua-module-text-0.1.2.1-K4GfIrO5QnpLtE7MQ9tZwg
depends:
    base-4.11.1.0 hslua-0.9.5.2-CX2X6eyDj0FC4ByTGvZ9Rr text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             hslua-0.9.5.2-CX2X6eyDj0FC4ByTGvZ9Rr=8ee0d1cf66270818d038f8219f4c2fdc
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
